# LiteDFS-Client

A distributed file system, based on Python3, tornado, inspired by HDFS.

It's for data processing cache, not for permanent storage!

All code based on Python3, do not use Python2!

It still under development, so, maybe have some bugs or not stable enough!

See more details at https://github.com/fiefdx/LiteDFS

# Deployment

## Install LiteDFS-Client
```bash
$ pip3 install litedfs-client
```
